import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import FileUploader from './FileUploader';


const TestFileUploader = FileUploader({
    block: purebem.of('test-file-uploader'),
    displayName: 'TestFileUploader',
    Spinner: () => (<div />)
});

test('should trigger file upload event when file is dropped', () => {
    const onFileUpload = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            onFileUpload={ onFileUpload } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    fileuploader.find('label').simulate('drop', { dataTransfer: { files } });
    expect(onFileUpload).toHaveBeenCalledWith(files[0]);
});

test('should not trigger file upload event when file is dropped and disabled', () => {
    const onFileUpload = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            disabled={ true }
            onFileUpload={ onFileUpload } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    fileuploader.find('label').simulate('drop', { dataTransfer: { files } });
    expect(onFileUpload).not.toHaveBeenCalled();
});

test('should trigger file upload change event when selecting file', () => {
    const onFileUpload = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            onFileUpload={ onFileUpload } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    // cheat: since we cannot trigger label click and file dialog.
    fileuploader.find('input').simulate('change', { target: { files } });
    expect(onFileUpload).toHaveBeenCalledWith(files[0]);
});

test('should trigger drag enter', () => {
    const onDragEnter = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            onDragEnter={ onDragEnter } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    fileuploader.find('label').simulate('dragEnter', { dataTransfer: { files } });
    expect(onDragEnter).toHaveBeenCalled();
});

test('should not trigger drag enter when disabled', () => {
    const onDragEnter = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            disabled={ true }
            onDragEnter={ onDragEnter } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    fileuploader.find('label').simulate('dragEnter', { dataTransfer: { files } });
    expect(onDragEnter).not.toHaveBeenCalled();
});

test('should trigger drag leave', () => {
    const onDragLeave = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            onDragLeave={ onDragLeave } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    fileuploader.find('label').simulate('dragLeave', { dataTransfer: { files } });
    expect(onDragLeave).toHaveBeenCalled();
});

test('should not trigger drag leave when disabled', () => {
    const onDragLeave = jest.fn();
    const fileuploader = mount(
        <TestFileUploader
            disabled={ true }
            onDragLeave={ onDragLeave } />
    );

    const files = [{
        name: 'foundation.pdf',
        size: 1024,
        type: 'application/pdf'
    }];

    fileuploader.find('label').simulate('dragLeave', { dataTransfer: { files } });
    expect(onDragLeave).not.toHaveBeenCalled();
});
